pub struct CarpGraph {
pub header: Vec<u8>,
pub dimensions: (u32, u32),
pub commands: Vec<Command>,
}Expand description
A graph is CarpGraph’s representation of an image. It’s essentially just a reproducable series of commands which a renderer can traverse to reconstruct an image.
Fields
header: Vec<u8>dimensions: (u32, u32)commands: Vec<Command>Implementations