pub struct UserStack {
pub id: usize,
pub created: usize,
pub owner: usize,
pub name: String,
pub users: Vec<usize>,
pub privacy: StackPrivacy,
pub mode: StackMode,
pub sort: StackSort,
pub is_locked: bool,
}Fields
id: usizecreated: usizeowner: usizename: Stringusers: Vec<usize>privacy: StackPrivacymode: StackModesort: StackSortis_locked: boolLocked stacks cannot be deleted or have their mode changed. Stacks cannot be locked after creation, and must be locked by the server.
Implementations