pub struct MediaUpload {
pub id: usize,
pub created: usize,
pub owner: usize,
pub bucket: String,
pub metadata: UploadMetadata,
}Fields
id: usizecreated: usizeowner: usizebucket: Stringmetadata: UploadMetadataImplementations
Sourceimpl MediaUpload
impl MediaUpload
Sourcepub fn new(what: MediaType, owner: usize, bucket: String) -> MediaUpload
pub fn new(what: MediaType, owner: usize, bucket: String) -> MediaUpload
Create a new MediaUpload.
Sourcepub fn full_path(&self, directory: &str) -> PathBufD
pub fn full_path(&self, directory: &str) -> PathBufD
Get the path to the fs file for this upload (with bucket).
Sourcepub fn path(&self, directory: &str) -> PathBufD
pub fn path(&self, directory: &str) -> PathBufD
Get the path to the fs file for this upload.
Uses path with bucket unless legacy path exists.